# ManeuverRecognition Package

ManeuverRecognition is a python package providing functions for the preprocessing of time series data for classification, the creation of predictive LSTM based  models and the evaluation of multi class predictions.

Its functionalities are demonstrated and the documentation is given here: https://github.com/Schuster-j/maneuverRecognition 